==> buzztard_0.5.0.orig.tar.gz: buzztard-0.5.0/src/ui/edit/main-page-info.h <==
/* $Id: main-page-info.h 1742 2008-04-16 06:30:00Z ensonic $
 *
 * Buzztard
 * Copyright (C) 2006 Buzztard team <buzztard-devel@lists.sf.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef BT_MAIN_PAGE_INFO_H
#define BT_MAIN_PAGE_INFO_H

#include <glib.h>
#include <glib-object.h>

#define BT_TYPE_MAIN_PAGE_INFO             (bt_main_page_info_get_type ())
#define BT_MAIN_PAGE_INFO(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), BT_TYPE_MAIN_PAGE_INFO, BtMainPageInfo))
#define BT_MAIN_PAGE_INFO_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), BT_TYPE_MAIN_PAGE_INFO, BtMainPageInfoClass))
#define BT_IS_MAIN_PAGE_INFO(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BT_TYPE_MAIN_PAGE_INFO))
#define BT_IS_MAIN_PAGE_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BT_TYPE_MAIN_PAGE_INFO))
#define BT_MAIN_PAGE_INFO_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), BT_TYPE_MAIN_PAGE_INFO, BtMainPageInfoClass))

/* type macros */

typedef struct _BtMainPageInfo BtMainPageInfo;
typedef struct _BtMainPageInfoClass BtMainPageInfoClass;
typedef struct _BtMainPageInfoPrivate BtMainPageInfoPrivate;

/**
 * BtMainPageInfo:
 *
 * the info page for the editor application
 */
struct _BtMainPageInfo {
  GtkVBox parent;
  
  /*< private >*/
  BtMainPageInfoPrivate *priv;
};
/* structure of the main-page-info class */
struct _BtMainPageInfoClass {
  GtkVBoxClass parent;
  
};

/* used by MAIN_PAGE_INFO_TYPE */
GType bt_main_page_info_get_type(void) G_GNUC_CONST;

#endif // BT_MAIN_PAGE_INFO_H

==> buzztard_0.6.0.orig.tar.gz: buzztard-0.6.0/src/ui/edit/main-page-info.h <==
/* $Id: main-page-info.h 3610 2011-08-26 13:50:26Z ensonic $
 *
 * Buzztard
 * Copyright (C) 2006 Buzztard team <buzztard-devel@lists.sf.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef BT_MAIN_PAGE_INFO_H
#define BT_MAIN_PAGE_INFO_H

#include <glib.h>
#include <glib-object.h>

#define BT_TYPE_MAIN_PAGE_INFO             (bt_main_page_info_get_type ())
#define BT_MAIN_PAGE_INFO(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), BT_TYPE_MAIN_PAGE_INFO, BtMainPageInfo))
#define BT_MAIN_PAGE_INFO_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), BT_TYPE_MAIN_PAGE_INFO, BtMainPageInfoClass))
#define BT_IS_MAIN_PAGE_INFO(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BT_TYPE_MAIN_PAGE_INFO))
#define BT_IS_MAIN_PAGE_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BT_TYPE_MAIN_PAGE_INFO))
#define BT_MAIN_PAGE_INFO_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), BT_TYPE_MAIN_PAGE_INFO, BtMainPageInfoClass))

/* type macros */

typedef struct _BtMainPageInfo BtMainPageInfo;
typedef struct _BtMainPageInfoClass BtMainPageInfoClass;
typedef struct _BtMainPageInfoPrivate BtMainPageInfoPrivate;

/**
 * BtMainPageInfo:
 *
 * the info page for the editor application
 */
struct _BtMainPageInfo {
  GtkVBox parent;
  
  /*< private >*/
  BtMainPageInfoPrivate *priv;
};

struct _BtMainPageInfoClass {
  GtkVBoxClass parent;
  
};

GType bt_main_page_info_get_type(void) G_GNUC_CONST;

#include "main-pages.h"

BtMainPageInfo *bt_main_page_info_new(const BtMainPages *pages);

#endif // BT_MAIN_PAGE_INFO_H
